@@ -43,7 +43,12 @@ def data_wrapper(data):
     if isinstance(df, pd.DataFrame):
         res["controls"] = [f.to_json(df) for f in filters]
         res["columns"] = [
-            {"title": x, "dataIndex": x, "key": x, "render": {"action": links[x]},}
+            {
+                "title": x,
+                "dataIndex": x,
+                "key": x,
+                "render": {"action": links[x]},
+            }
             if x in links
             else {"title": x, "dataIndex": x, "key": x}
             for x in df.columns
@@ -55,7 +60,10 @@ def data_wrapper(data):
         df = df.applymap(str)
         res["dataSource"] = json.loads(
             df.to_json(
-                orient="records", date_format="iso", date_unit="s", force_ascii=False,
+                orient="records",
+                date_format="iso",
+                date_unit="s",
+                force_ascii=False,
             )
         )
         # logger.debug("res dataSource lens: " + str(len(res["dataSource"])))
@@ -91,9 +99,13 @@ class Data(object):
             ret = conn.hget("sachima_results", req_md5)
             conn.zincrby("sachima_board", 1, req_md5)  # 监控访问次数
 
-        except:
+        except Exception as ex:
             # print(TypeError, ValueError)
-            logger.info("cache exception, fallbacking..... will not use cache")
+            logger.info(
+                "cache exception {} raised, fallbacking..... will not use cache".format(
+                    str(ex)
+                )
+            )
             need_fallback = True  # 缓存出现异常，需要降级回退处理
 
         # 不需要降级并且有返回值并且前端没有要求强制刷新并且命中缓存
@@ -124,7 +136,8 @@ class Data(object):
     def writecache(self, name, value, conn=RedisClient().conn):
         logger.debug("writecache to: " + name)
         conn.rpush(
-            name, json.dumps(value, indent=2, ensure_ascii=False).encode("utf-8"),
+            name,
+            json.dumps(value, indent=2, ensure_ascii=False).encode("utf-8"),
         )
 
     @rpc
